# TODO

**Generated by:** prefact v0.1.30
**Generated on:** 2026-03-31T14:44:49.072632
**Total issues:** 397 active, 0 completed

---

## 📋 Current Issues

- [ ] examples/02_ast_comparison/main.py:55 - Function 'main' missing return type (suggested: -> None)
- [ ] examples/02_ast_comparison/main.py:74 - String concatenation can be converted to f-string
- [ ] examples/02_ast_comparison/main.py:91 - String concatenation can be converted to f-string
- [ ] examples/02_ast_comparison/main.py:106 - String concatenation can be converted to f-string
- [ ] examples/02_ast_comparison/main.py:6 - Unused import: 'json'
- [ ] examples/02_ast_comparison/main.py:7 - Unused import: 'Path'
- [ ] examples/02_ast_comparison/main.py:10 - Unused import: 'parse_code'
- [ ] examples/02_ast_comparison/main.py:9 - Suspicious import: from examples.utils
- [ ] examples/02_ast_comparison/main.py:55 - standalone main function
- [ ] examples/02_ast_comparison/main.py:114 - module execution block
- [ ] examples/04_graph_analysis/main.py:65 - Function 'main' missing return type (suggested: -> None)
- [ ] examples/04_graph_analysis/main.py:89 - String concatenation can be converted to f-string
- [ ] examples/04_graph_analysis/main.py:111 - String concatenation can be converted to f-string
- [ ] examples/04_graph_analysis/main.py:145 - String concatenation can be converted to f-string
- [ ] examples/04_graph_analysis/main.py:6 - Unused import: 'json'
- [ ] examples/04_graph_analysis/main.py:7 - Unused import: 'Path'
- [ ] examples/04_graph_analysis/main.py:9 - Suspicious import: from examples.utils
- [ ] examples/04_graph_analysis/main.py:27 - standalone main function
- [ ] examples/04_graph_analysis/main.py:57 - standalone main function
- [ ] examples/04_graph_analysis/main.py:65 - standalone main function
- [ ] examples/01_basic_validation/main.py:57 - Function 'main' missing return type (suggested: -> None)
- [ ] examples/01_basic_validation/main.py:6 - Unused import: 'json'
- [ ] examples/01_basic_validation/main.py:7 - Unused import: 'os'
- [ ] examples/01_basic_validation/main.py:9 - Unused import: 'Proposal'
- [ ] examples/01_basic_validation/main.py:59 - Duplicate import: 'Path' (first at line 8)
- [ ] examples/01_basic_validation/main.py:61 - Suspicious import: from examples.utils
- [ ] examples/01_basic_validation/main.py:57 - standalone main function
- [ ] examples/01_basic_validation/main.py:76 - module execution block
- [ ] examples/03_security_check/main.py:65 - Function 'main' missing return type (suggested: -> None)
- [ ] examples/03_security_check/main.py:86 - String concatenation can be converted to f-string
- [ ] examples/03_security_check/main.py:107 - String concatenation can be converted to f-string
- [ ] examples/03_security_check/main.py:6 - Unused import: 'json'
- [ ] examples/03_security_check/main.py:7 - Unused import: 'Path'
- [ ] examples/03_security_check/main.py:10 - Unused import: 'VallmSettings'
- [ ] examples/03_security_check/main.py:9 - Suspicious import: from examples.utils
- [ ] examples/03_security_check/main.py:65 - standalone main function
- [ ] examples/03_security_check/main.py:114 - module execution block
- [ ] examples/05_llm_semantic_review/main.py:66 - Function 'main' missing return type (suggested: -> None)
- [ ] examples/05_llm_semantic_review/main.py:102 - String concatenation can be converted to f-string
- [ ] examples/05_llm_semantic_review/main.py:11 - Unused import: 'json'
- [ ] examples/05_llm_semantic_review/main.py:12 - Unused import: 'Path'
- [ ] examples/05_llm_semantic_review/main.py:14 - Unused import: 'save_analysis_data'
- [ ] examples/05_llm_semantic_review/main.py:14 - Suspicious import: from examples.utils
- [ ] examples/05_llm_semantic_review/main.py:66 - standalone main function
- [ ] examples/05_llm_semantic_review/main.py:124 - module execution block
- [ ] examples/05_llm_semantic_review/main_template.py:57 - Function 'main' missing return type (suggested: -> None)
- [ ] examples/05_llm_semantic_review/main_template.py:6 - Unused import: 'json'
- [ ] examples/05_llm_semantic_review/main_template.py:7 - Unused import: 'os'
- [ ] examples/05_llm_semantic_review/main_template.py:8 - Unused import: 'Path'
- [ ] examples/05_llm_semantic_review/main_template.py:58 - Suspicious import: from examples.utils
- [ ] examples/05_llm_semantic_review/main_template.py:57 - standalone main function
- [ ] examples/05_llm_semantic_review/main_template.py:73 - module execution block
- [ ] examples/06_multilang_validation/main_template.py:57 - Function 'main' missing return type (suggested: -> None)
- [ ] examples/06_multilang_validation/main_template.py:6 - Unused import: 'json'
- [ ] examples/06_multilang_validation/main_template.py:7 - Unused import: 'os'
- [ ] examples/06_multilang_validation/main_template.py:8 - Unused import: 'Path'
- [ ] examples/06_multilang_validation/main_template.py:58 - Suspicious import: from examples.utils
- [ ] examples/06_multilang_validation/main_template.py:57 - standalone main function
- [ ] examples/06_multilang_validation/main_template.py:73 - module execution block
- [ ] examples/06_multilang_validation/main.py:177 - Function 'main' missing return type (suggested: -> None)
- [ ] examples/06_multilang_validation/main.py:177 - standalone main function
- [ ] examples/06_multilang_validation/main.py:216 - module execution block
- [ ] examples/07_multi_language/main.py:170 - Function 'test_language_detection' missing return type (suggested: -> None)
- [ ] examples/07_multi_language/main.py:222 - Function 'validate_all_languages' missing return type (suggested: -> Any)
- [ ] examples/07_multi_language/main.py:254 - Function 'save_results' missing return type (suggested: -> None)
- [ ] examples/07_multi_language/main.py:307 - String concatenation can be converted to f-string
- [ ] examples/07_multi_language/main.py:299 - standalone main function
- [ ] examples/07_multi_language/main.py:326 - module execution block
- [ ] examples/10_mcp_ollama_demo/legacy_code/order_processor.py:13 - Function 'process_order' missing return type (suggested: -> Any)
- [ ] examples/10_mcp_ollama_demo/legacy_code/order_processor.py:34 - Function 'load_config' missing return type (suggested: -> Any)
- [ ] examples/10_mcp_ollama_demo/legacy_code/order_processor.py:40 - Function 'save_data' missing return type (suggested: -> None)
- [ ] examples/10_mcp_ollama_demo/legacy_code/order_processor.py:50 - String concatenation can be converted to f-string
- [ ] examples/10_mcp_ollama_demo/legacy_code/order_processor.py:6 - Unused import: 'json'
- [ ] examples/10_mcp_ollama_demo/legacy_code/order_processor.py:8 - Unused import: 'datetime'
- [ ] examples/10_mcp_ollama_demo/legacy_code/order_processor.py:90 - Duplicate import: 'os' (first at line 7)
- [ ] examples/10_mcp_ollama_demo/legacy_code/order_processor.py:121 - Magic number in comparison: 50
- [ ] examples/10_mcp_ollama_demo/legacy_code/order_processor.py:121 - Magic number: 50 - use named constant
- [ ] examples/10_mcp_ollama_demo/legacy_code/order_processor.py:122 - Magic number: 10.99 - use named constant
- [ ] examples/08_code2llm_integration/main.py:215 - Function 'main' missing return type (suggested: -> None)
- [ ] examples/08_code2llm_integration/main.py:129 - String concatenation can be converted to f-string
- [ ] examples/08_code2llm_integration/main.py:202 - String concatenation can be converted to f-string
- [ ] examples/08_code2llm_integration/main.py:120 - String concatenation can be converted to f-string
- [ ] examples/08_code2llm_integration/main.py:60 - standalone main function
- [ ] examples/08_code2llm_integration/main.py:67 - module execution block
- [ ] examples/08_code2llm_integration/main.py:215 - standalone main function
- [ ] examples/09_code2logic_integration/main.py:260 - Function 'main' missing return type (suggested: -> None)
- [ ] examples/09_code2logic_integration/main.py:123 - String concatenation can be converted to f-string
- [ ] examples/09_code2logic_integration/main.py:170 - String concatenation can be converted to f-string
- [ ] examples/09_code2logic_integration/main.py:288 - String concatenation can be converted to f-string
- [ ] examples/09_code2logic_integration/main.py:18 - Unused import: 'Language'
- [ ] examples/09_code2logic_integration/main.py:18 - Unused import: 'detect_language'
- [ ] examples/09_code2logic_integration/main.py:248 - Duplicate import: 'generate_dot' (first at line 11)
- [ ] examples/09_code2logic_integration/main.py:260 - standalone main function
- [ ] examples/09_code2logic_integration/main.py:297 - module execution block
- [ ] examples/10_mcp_ollama_demo/mcp_demo.py:46 - Function 'log_section' missing return type (suggested: -> None)
- [ ] examples/10_mcp_ollama_demo/mcp_demo.py:54 - Function 'log_step' missing return type (suggested: -> None)
- [ ] examples/10_mcp_ollama_demo/mcp_demo.py:60 - Function 'log_code' missing return type (suggested: -> None)
- [ ] examples/10_mcp_ollama_demo/mcp_demo.py:64 - String concatenation can be converted to f-string
- [ ] examples/10_mcp_ollama_demo/mcp_demo.py:278 - String concatenation can be converted to f-string
- [ ] examples/10_mcp_ollama_demo/mcp_demo.py:13 - Unused import: 'json'
- [ ] examples/10_mcp_ollama_demo/mcp_demo.py:16 - Unused import: 'time'
- [ ] examples/10_mcp_ollama_demo/mcp_demo.py:18 - Unused import: 'Optional'
- [ ] examples/10_mcp_ollama_demo/mcp_demo.py:22 - Suspicious import: from examples.utils
- [ ] examples/10_mcp_ollama_demo/mcp_demo.py:60 - Magic number: 30 - use named constant
- [ ] examples/10_mcp_ollama_demo/mcp_demo.py:283 - Magic number: 50 - use named constant
- [ ] examples/10_mcp_ollama_demo/mcp_demo.py:203 - Magic number: 120 - use named constant
- [ ] examples/10_mcp_ollama_demo/mcp_demo.py:360 - standalone main function
- [ ] examples/10_mcp_ollama_demo/mcp_demo.py:400 - module execution block
- [ ] examples/10_mcp_ollama_demo/refactored_output.py:105 - Function 'main' missing return type (suggested: -> None)
- [ ] examples/10_mcp_ollama_demo/refactored_output.py:3 - Unused import: 'datetime'
- [ ] examples/10_mcp_ollama_demo/refactored_output.py:4 - Unused import: 'Optional'
- [ ] examples/10_mcp_ollama_demo/refactored_output.py:5 - Unused import: 'subprocess'
- [ ] examples/10_mcp_ollama_demo/refactored_output.py:70 - Magic number in comparison: 50
- [ ] examples/10_mcp_ollama_demo/refactored_output.py:70 - Magic number: 50 - use named constant
- [ ] examples/10_mcp_ollama_demo/refactored_output.py:71 - Magic number: 10.99 - use named constant
- [ ] examples/10_mcp_ollama_demo/refactored_output.py:105 - standalone main function
- [ ] examples/10_mcp_ollama_demo/refactored_output.py:126 - module execution block
- [ ] examples/11_claude_code_autonomous/legacy_code/data_processor.py:19 - Function 'load_config' missing return type (suggested: -> Any)
- [ ] examples/11_claude_code_autonomous/legacy_code/data_processor.py:24 - Function 'init_database' missing return type (suggested: -> None)
- [ ] examples/11_claude_code_autonomous/legacy_code/data_processor.py:191 - Function 'main' missing return type (suggested: -> None)
- [ ] examples/11_claude_code_autonomous/legacy_code/data_processor.py:145 - String concatenation can be converted to f-string
- [ ] examples/11_claude_code_autonomous/legacy_code/data_processor.py:156 - String concatenation can be converted to f-string
- [ ] examples/11_claude_code_autonomous/legacy_code/data_processor.py:10 - Unused import: 'sys'
- [ ] examples/11_claude_code_autonomous/legacy_code/data_processor.py:12 - Unused import: 'List'
- [ ] examples/11_claude_code_autonomous/legacy_code/data_processor.py:12 - Unused import: 'Dict'
- [ ] examples/11_claude_code_autonomous/legacy_code/data_processor.py:191 - standalone main function
- [ ] examples/11_claude_code_autonomous/legacy_code/data_processor.py:223 - module execution block
- [ ] examples/11_claude_code_autonomous/claude_autonomous_demo.py:50 - Function 'log_section' missing return type (suggested: -> None)
- [ ] examples/11_claude_code_autonomous/claude_autonomous_demo.py:58 - Function 'log_step' missing return type (suggested: -> None)
- [ ] examples/11_claude_code_autonomous/claude_autonomous_demo.py:64 - Function 'log_code' missing return type (suggested: -> None)
- [ ] examples/11_claude_code_autonomous/claude_autonomous_demo.py:68 - String concatenation can be converted to f-string
- [ ] examples/11_claude_code_autonomous/claude_autonomous_demo.py:546 - String concatenation can be converted to f-string
- [ ] examples/11_claude_code_autonomous/claude_autonomous_demo.py:19 - Unused import: 'time'
- [ ] examples/11_claude_code_autonomous/claude_autonomous_demo.py:23 - Unused import: 'List'
- [ ] examples/11_claude_code_autonomous/claude_autonomous_demo.py:23 - Unused import: 'Tuple'
- [ ] examples/11_claude_code_autonomous/claude_autonomous_demo.py:601 - Duplicate import: 'os' (first at line 16)
- [ ] examples/11_claude_code_autonomous/claude_autonomous_demo.py:22 - Suspicious import: from examples.utils
- [ ] examples/11_claude_code_autonomous/claude_autonomous_demo.py:64 - Magic number: 30 - use named constant
- [ ] examples/11_claude_code_autonomous/claude_autonomous_demo.py:164 - Magic number: 4000 - use named constant
- [ ] examples/11_claude_code_autonomous/claude_autonomous_demo.py:175 - Magic number: 120 - use named constant
- [ ] examples/11_claude_code_autonomous/claude_autonomous_demo.py:346 - module execution block
- [ ] examples/11_claude_code_autonomous/claude_autonomous_demo.py:598 - standalone main function
- [ ] examples/11_claude_code_autonomous/claude_autonomous_demo.py:649 - module execution block
- [ ] examples/12_ollama_simple_demo/best_version.py:13 - Relative import (level=1): '.utils'
- [ ] examples/12_ollama_simple_demo/best_version.py:18 - Relative import (level=1): '.utils'
- [ ] examples/12_ollama_simple_demo/best_version.py:16 - Function 'main' missing return type (suggested: -> None)
- [ ] examples/12_ollama_simple_demo/best_version.py:6 - Unused import: 'os'
- [ ] examples/12_ollama_simple_demo/best_version.py:7 - Unused import: 'json'
- [ ] examples/12_ollama_simple_demo/best_version.py:8 - Unused import: 'List'
- [ ] examples/12_ollama_simple_demo/best_version.py:16 - standalone main function
- [ ] examples/12_ollama_simple_demo/best_version.py:21 - module execution block
- [ ] examples/12_ollama_simple_demo/iteration_1.py:13 - Relative import (level=1): '.utils'
- [ ] examples/12_ollama_simple_demo/iteration_1.py:18 - Relative import (level=1): '.utils'
- [ ] examples/12_ollama_simple_demo/iteration_1.py:16 - Function 'main' missing return type (suggested: -> None)
- [ ] examples/12_ollama_simple_demo/iteration_1.py:6 - Unused import: 'os'
- [ ] examples/12_ollama_simple_demo/iteration_1.py:7 - Unused import: 'json'
- [ ] examples/12_ollama_simple_demo/iteration_1.py:8 - Unused import: 'List'
- [ ] examples/12_ollama_simple_demo/iteration_1.py:16 - standalone main function
- [ ] examples/12_ollama_simple_demo/iteration_1.py:21 - module execution block
- [ ] examples/12_ollama_simple_demo/iteration_2.py:13 - Relative import (level=1): '.utils'
- [ ] examples/12_ollama_simple_demo/iteration_2.py:18 - Relative import (level=1): '.utils'
- [ ] examples/12_ollama_simple_demo/iteration_2.py:16 - Function 'main' missing return type (suggested: -> None)
- [ ] examples/12_ollama_simple_demo/iteration_2.py:6 - Unused import: 'os'
- [ ] examples/12_ollama_simple_demo/iteration_2.py:7 - Unused import: 'json'
- [ ] examples/12_ollama_simple_demo/iteration_2.py:8 - Unused import: 'List'
- [ ] examples/12_ollama_simple_demo/iteration_2.py:16 - standalone main function
- [ ] examples/12_ollama_simple_demo/iteration_2.py:21 - module execution block
- [ ] examples/12_ollama_simple_demo/legacy_code/simple_buggy.py:12 - Function 'process_user_input' missing return type (suggested: -> Any)
- [ ] examples/12_ollama_simple_demo/legacy_code/simple_buggy.py:29 - Function 'load_config' missing return type (suggested: -> Any)
- [ ] examples/12_ollama_simple_demo/legacy_code/simple_buggy.py:34 - Function 'save_data' missing return type (suggested: -> None)
- [ ] examples/12_ollama_simple_demo/legacy_code/simple_buggy.py:102 - Magic number: 20 - use named constant
- [ ] examples/12_ollama_simple_demo/legacy_code/simple_buggy.py:90 - standalone main function
- [ ] examples/12_ollama_simple_demo/legacy_code/simple_buggy.py:111 - module execution block
- [ ] examples/12_ollama_simple_demo/ollama_simple_demo.py:42 - Function 'log_section' missing return type (suggested: -> None)
- [ ] examples/12_ollama_simple_demo/ollama_simple_demo.py:48 - Function 'log_step' missing return type (suggested: -> None)
- [ ] examples/12_ollama_simple_demo/ollama_simple_demo.py:191 - Function 'run_simple_workflow' missing return type (suggested: -> Dict)
- [ ] examples/12_ollama_simple_demo/ollama_simple_demo.py:206 - String concatenation can be converted to f-string
- [ ] examples/12_ollama_simple_demo/ollama_simple_demo.py:252 - String concatenation can be converted to f-string
- [ ] examples/12_ollama_simple_demo/ollama_simple_demo.py:334 - String concatenation can be converted to f-string
- [ ] examples/12_ollama_simple_demo/ollama_simple_demo.py:8 - Unused import: 'json'
- [ ] examples/12_ollama_simple_demo/ollama_simple_demo.py:10 - Unused import: 'os'
- [ ] examples/12_ollama_simple_demo/ollama_simple_demo.py:11 - Unused import: 'subprocess'
- [ ] examples/12_ollama_simple_demo/ollama_simple_demo.py:19 - Suspicious import: from examples.utils
- [ ] examples/12_ollama_simple_demo/ollama_simple_demo.py:199 - Magic number in comparison: 200
- [ ] examples/12_ollama_simple_demo/ollama_simple_demo.py:199 - Magic number: 200 - use named constant
- [ ] examples/12_ollama_simple_demo/ollama_simple_demo.py:291 - standalone main function
- [ ] examples/12_ollama_simple_demo/ollama_simple_demo.py:339 - module execution block
- [ ] examples/12_ollama_simple_demo/utils/calculate_total.py:3 - Unused import: 'annotations'
- [ ] examples/12_ollama_simple_demo/utils/calculate_total.py:8 - LLM-style docstring in calculate_total
- [ ] examples/12_ollama_simple_demo/utils/__init__.py:5 - Relative import (level=1): '.calculate_total'
- [ ] examples/12_ollama_simple_demo/utils/__init__.py:6 - Relative import (level=1): '.load_config'
- [ ] examples/12_ollama_simple_demo/utils/__init__.py:7 - Relative import (level=1): '.main'
- [ ] examples/12_ollama_simple_demo/utils/__init__.py:3 - Unused import: 'annotations'
- [ ] examples/12_ollama_simple_demo/utils/load_config.py:3 - Unused import: 'annotations'
- [ ] examples/12_ollama_simple_demo/utils/load_config.py:8 - LLM-style docstring in load_config
- [ ] examples/12_ollama_simple_demo/utils/main.py:10 - Relative import (level=1): '.load_config'
- [ ] examples/12_ollama_simple_demo/utils/main.py:11 - Relative import (level=1): '.process_user_input'
- [ ] examples/12_ollama_simple_demo/utils/main.py:12 - Relative import (level=1): '.calculate_total'
- [ ] examples/12_ollama_simple_demo/utils/main.py:3 - Unused import: 'annotations'
- [ ] examples/12_ollama_simple_demo/utils/main.py:5 - Unused import: 'Any'
- [ ] examples/12_ollama_simple_demo/utils/main.py:5 - Unused import: 'Dict'
- [ ] examples/12_ollama_simple_demo/utils/main.py:25 - Magic number: 20 - use named constant
- [ ] examples/12_ollama_simple_demo/utils/process_user_input.py:3 - Unused import: 'annotations'
- [ ] examples/12_ollama_simple_demo/utils/process_user_input.py:6 - LLM-style docstring in process_user_input
- [ ] examples/12_ollama_simple_demo/utils/save_data.py:3 - Unused import: 'annotations'
- [ ] examples/12_ollama_simple_demo/utils/save_data.py:10 - LLM-style docstring in save_data
- [ ] examples/mcp_demo.py:27 - Function 'example_syntax_validation' missing return type (suggested: -> None)
- [ ] examples/mcp_demo.py:61 - Function 'example_security_validation' missing return type (suggested: -> None)
- [ ] examples/mcp_demo.py:90 - Function 'example_full_pipeline' missing return type (suggested: -> None)
- [ ] examples/mcp_demo.py:8 - Unused import: 'json'
- [ ] examples/mcp_demo.py:19 - Unused import: 'validate_imports'
- [ ] examples/mcp_demo.py:96 - Import of non-existent module detected
- [ ] examples/mcp_demo.py:27 - Suspicious function name: example_syntax_validation
- [ ] examples/mcp_demo.py:61 - Suspicious function name: example_security_validation
- [ ] examples/mcp_demo.py:181 - Magic number: 40 - use named constant
- [ ] examples/mcp_demo.py:27 - Example function in production code
- [ ] examples/mcp_demo.py:61 - Example function in production code
- [ ] examples/mcp_demo.py:90 - Example function in production code
- [ ] examples/mcp_demo.py:178 - standalone main function
- [ ] examples/mcp_demo.py:205 - module execution block
- [ ] examples/utils/extract_code_from_response.py:3 - Unused import: 'annotations'
- [ ] examples/utils/extract_code_from_response.py:8 - LLM-style docstring in extract_code_from_response
- [ ] examples/utils/__init__.py:12 - Relative import (level=1): '.extract_code_from_response'
- [ ] examples/utils/__init__.py:121 - String concatenation can be converted to f-string
- [ ] examples/utils/__init__.py:191 - String concatenation can be converted to f-string
- [ ] examples/utils/__init__.py:4 - Unused import: 'os'
- [ ] examples/utils/__init__.py:6 - Unused import: 'Any'
- [ ] examples/utils/__init__.py:12 - Unused import: 'extract_code_from_response'
- [ ] examples/utils/__init__.py:144 - Duplicate import: 'validate' (first at line 10)
- [ ] examples/utils/__init__.py:144 - Duplicate import: 'Proposal' (first at line 9)
- [ ] examples/utils/__init__.py:15 - LLM-style docstring in save_analysis_data
- [ ] examples/utils/__init__.py:33 - LLM-style docstring in run_validation_examples
- [ ] examples/utils/__init__.py:128 - LLM-style docstring in validate_code_example
- [ ] examples/utils/extraction.py:7 - LLM-style docstring in extract_code_from_response
- [ ] examples/utils/extraction.py:41 - LLM-style docstring in extract_json_from_response
- [ ] examples/utils/logging_utils.py:55 - String concatenation can be converted to f-string
- [ ] examples/utils/logging_utils.py:4 - Unused import: 'Optional'
- [ ] examples/utils/logging_utils.py:45 - Magic number: 30 - use named constant
- [ ] examples/utils/logging_utils.py:28 - Magic number: 80 - use named constant
- [ ] examples/utils/logging_utils.py:30 - Magic number: 80 - use named constant
- [ ] examples/utils/logging_utils.py:22 - LLM-style docstring in log_section
- [ ] examples/utils/logging_utils.py:34 - LLM-style docstring in log_step
- [ ] examples/utils/logging_utils.py:45 - LLM-style docstring in log_code
- [ ] examples/utils/save_analysis_data.py:3 - Unused import: 'annotations'
- [ ] examples/utils/save_analysis_data.py:10 - LLM-style docstring in save_analysis_data
- [ ] examples/utils/validation_runner.py:100 - String concatenation can be converted to f-string
- [ ] examples/utils/validation_runner.py:3 - Unused import: 'annotations'
- [ ] examples/utils/validation_runner.py:12 - LLM-style docstring in run_validation_examples
- [ ] mcp/server/_tools_vallm.py:14 - Unused import: 'annotations'
- [ ] mcp/server/_tools_vallm.py:16 - Unused import: 'json'
- [ ] mcp/server/_tools_vallm.py:25 - Unused import: 'ValidationResult'
- [ ] mcp/server/_tools_vallm.py:124 - LLM-style docstring in validate_syntax
- [ ] mcp/server/_tools_vallm.py:167 - LLM-style docstring in validate_imports
- [ ] mcp/server/_tools_vallm.py:210 - LLM-style docstring in validate_security
- [ ] mcp/server/self_server.py:146 - Function 'main' missing return type (suggested: -> None)
- [ ] mcp/server/self_server.py:90 - Magic number: 32601 - use named constant
- [ ] mcp/server/self_server.py:117 - Magic number: 32603 - use named constant
- [ ] mcp/server/self_server.py:140 - Magic number: 32601 - use named constant
- [ ] mcp/server/self_server.py:146 - standalone main function
- [ ] mcp/server/self_server.py:184 - module execution block
- [ ] mcp_server.py:27 - module execution block
- [ ] scripts/bump_version.py:12 - Function 'bump_version' missing return type (suggested: -> Any)
- [ ] scripts/bump_version.py:36 - Function 'main' missing return type (suggested: -> None)
- [ ] scripts/bump_version.py:36 - standalone main function
- [ ] scripts/bump_version.py:77 - module execution block
- [ ] src/vallm/cli/__init__.py:3 - Unused import: 'annotations'
- [ ] src/vallm/cli/batch_processor.py:3 - Unused import: 'annotations'
- [ ] src/vallm/cli/batch_processor.py:18 - Unused import: 'Verdict'
- [ ] src/vallm/cli/batch_processor.py:188 - Duplicate import: 'fnmatch' (first at line 138)
- [ ] src/vallm/cli/batch_processor.py:212 - Duplicate import: 'fnmatch' (first at line 138)
- [ ] src/vallm/cli/batch_processor.py:225 - Duplicate import: 'output_batch_empty' (first at line 10)
- [ ] src/vallm/cli/command_handlers.py:3 - Unused import: 'annotations'
- [ ] src/vallm/cli/command_handlers.py:89 - Duplicate import: 'validate' (first at line 60)
- [ ] src/vallm/cli/command_handlers.py:124 - Duplicate import: 'BatchProcessor' (first at line 11)
- [ ] src/vallm/cli/command_handlers.py:261 - Duplicate import: 'Proposal' (first at line 16)
- [ ] src/vallm/cli/output_formatters.py:166 - String concatenation can be converted to f-string
- [ ] src/vallm/cli/output_formatters.py:3 - Unused import: 'annotations'
- [ ] src/vallm/cli/settings_builders.py:3 - Unused import: 'annotations'
- [ ] src/vallm/config.py:3 - Unused import: 'annotations'
- [ ] src/vallm/config.py:39 - Magic number: 15 - use named constant
- [ ] src/vallm/config.py:40 - Magic number: 20 - use named constant
- [ ] src/vallm/config.py:51 - Magic number: 30 - use named constant
- [ ] src/vallm/cli.py:3 - Unused import: 'annotations'
- [ ] src/vallm/cli.py:7 - module execution block
- [ ] src/vallm/core/__init__.py:3 - Unused import: 'Language'
- [ ] src/vallm/core/__init__.py:3 - Unused import: 'detect_language'
- [ ] src/vallm/core/__init__.py:3 - Unused import: 'get_language_for_validation'
- [ ] src/vallm/core/ast_compare.py:11 - Function 'parse_code' missing return type (suggested: -> Any)
- [ ] src/vallm/core/ast_compare.py:41 - Function 'visit_Name' missing return type (suggested: -> Any)
- [ ] src/vallm/core/ast_compare.py:45 - Function 'visit_FunctionDef' missing return type (suggested: -> Any)
- [ ] src/vallm/core/ast_compare.py:3 - Unused import: 'annotations'
- [ ] src/vallm/core/graph_builder.py:58 - Function 'visit_Import' missing return type (suggested: -> None)
- [ ] src/vallm/core/graph_builder.py:70 - Function 'visit_ImportFrom' missing return type (suggested: -> None)
- [ ] src/vallm/core/graph_builder.py:83 - Function 'visit_FunctionDef' missing return type (suggested: -> None)
- [ ] src/vallm/core/graph_builder.py:3 - Unused import: 'annotations'
- [ ] src/vallm/core/gitignore.py:146 - String concatenation can be converted to f-string
- [ ] src/vallm/core/gitignore.py:112 - String concatenation can be converted to f-string
- [ ] src/vallm/core/gitignore.py:3 - Unused import: 'annotations'
- [ ] src/vallm/core/gitignore.py:248 - LLM-style docstring in should_exclude
- [ ] src/vallm/core/graph_diff.py:3 - Unused import: 'annotations'
- [ ] src/vallm/core/languages.py:112 - String concatenation can be converted to f-string
- [ ] src/vallm/core/languages.py:3 - Unused import: 'annotations'
- [ ] src/vallm/core/languages.py:5 - Unused import: 'auto'
- [ ] src/vallm/core/languages.py:179 - LLM-style docstring in detect_language
- [ ] src/vallm/core/languages.py:95 - LLM-style docstring in __init__
- [ ] src/vallm/hookspecs.py:3 - Unused import: 'annotations'
- [ ] src/vallm/core/proposal.py:3 - Unused import: 'annotations'
- [ ] src/vallm/sandbox/runner.py:77 - String concatenation can be converted to f-string
- [ ] src/vallm/sandbox/runner.py:3 - Unused import: 'annotations'
- [ ] src/vallm/sandbox/runner.py:5 - Unused import: 'field'
- [ ] src/vallm/sandbox/runner.py:127 - Magic number: 50000 - use named constant
- [ ] src/vallm/sandbox/runner.py:92 - Magic number: 124 - use named constant
- [ ] src/vallm/scoring.py:3 - Unused import: 'annotations'
- [ ] src/vallm/scoring.py:124 - LLM-style docstring in validate
- [ ] src/vallm/validators/base.py:3 - Unused import: 'annotations'
- [ ] src/vallm/validators/complexity.py:3 - Unused import: 'annotations'
- [ ] src/vallm/validators/complexity.py:12 - Unused import: 'Language'
- [ ] src/vallm/validators/complexity.py:90 - Magic number in comparison: 20
- [ ] src/vallm/validators/complexity.py:90 - Magic number: 20 - use named constant
- [ ] src/vallm/validators/imports/__init__.py:3 - Relative import (level=1): '.base'
- [ ] src/vallm/validators/imports/__init__.py:4 - Relative import (level=1): '.factory'
- [ ] src/vallm/validators/imports/__init__.py:5 - Relative import (level=1): '.python_imports'
- [ ] src/vallm/validators/imports/c_imports.py:6 - Relative import (level=1): '.base'
- [ ] src/vallm/validators/imports/c_imports.py:43 - Function 'walk' missing return type (suggested: -> None)
- [ ] src/vallm/validators/imports/c_imports.py:48 - String concatenation can be converted to f-string
- [ ] src/vallm/validators/imports/c_imports.py:52 - String concatenation can be converted to f-string
- [ ] src/vallm/validators/imports/factory.py:4 - Relative import (level=1): '.base'
- [ ] src/vallm/validators/imports/factory.py:5 - Relative import (level=1): '.python_imports'
- [ ] src/vallm/validators/imports/factory.py:6 - Relative import (level=1): '.javascript_imports'
- [ ] src/vallm/validators/imports/factory.py:41 - Function 'register_validator' missing return type (suggested: -> None)
- [ ] src/vallm/validators/imports/go_imports.py:6 - Relative import (level=1): '.base'
- [ ] src/vallm/validators/imports/go_imports.py:42 - Function 'walk' missing return type (suggested: -> None)
- [ ] src/vallm/validators/imports/go_imports.py:67 - String concatenation can be converted to f-string
- [ ] src/vallm/validators/imports/go_imports.py:49 - String concatenation can be converted to f-string
- [ ] src/vallm/validators/imports/go_imports.py:56 - String concatenation can be converted to f-string
- [ ] src/vallm/validators/imports/go_imports.py:4 - Unused import: 'Proposal'
- [ ] src/vallm/validators/imports/go_imports.py:5 - Unused import: 'Issue'
- [ ] src/vallm/validators/imports/go_imports.py:5 - Unused import: 'Severity'
- [ ] src/vallm/validators/imports/java_imports.py:6 - Relative import (level=1): '.base'
- [ ] src/vallm/validators/imports/java_imports.py:40 - Function 'walk' missing return type (suggested: -> None)
- [ ] src/vallm/validators/imports/java_imports.py:46 - String concatenation can be converted to f-string
- [ ] src/vallm/validators/imports/java_imports.py:4 - Unused import: 'Proposal'
- [ ] src/vallm/validators/imports/java_imports.py:5 - Unused import: 'Issue'
- [ ] src/vallm/validators/imports/java_imports.py:5 - Unused import: 'Severity'
- [ ] src/vallm/validators/imports/javascript_imports.py:6 - Relative import (level=1): '.base'
- [ ] src/vallm/validators/imports/javascript_imports.py:53 - Function 'walk' missing return type (suggested: -> None)
- [ ] src/vallm/validators/imports/javascript_imports.py:64 - String concatenation can be converted to f-string
- [ ] src/vallm/validators/imports/javascript_imports.py:91 - String concatenation can be converted to f-string
- [ ] src/vallm/validators/imports/javascript_imports.py:73 - String concatenation can be converted to f-string
- [ ] src/vallm/validators/imports/python_imports.py:9 - Relative import (level=1): '.base'
- [ ] src/vallm/validators/imports/rust_imports.py:6 - Relative import (level=1): '.base'
- [ ] src/vallm/validators/imports/rust_imports.py:41 - Function 'walk' missing return type (suggested: -> None)
- [ ] src/vallm/validators/imports/rust_imports.py:67 - String concatenation can be converted to f-string
- [ ] src/vallm/validators/imports/rust_imports.py:47 - String concatenation can be converted to f-string
- [ ] src/vallm/validators/imports/rust_imports.py:54 - String concatenation can be converted to f-string
- [ ] src/vallm/validators/imports/rust_imports.py:4 - Unused import: 'Proposal'
- [ ] src/vallm/validators/imports/rust_imports.py:5 - Unused import: 'Issue'
- [ ] src/vallm/validators/imports/rust_imports.py:5 - Unused import: 'Severity'
- [ ] src/vallm/validators/imports/utils.py:81 - String concatenation can be converted to f-string
- [ ] src/vallm/validators/imports/utils.py:34 - LLM-style docstring in walk
- [ ] src/vallm/validators/imports/utils.py:91 - LLM-style docstring in validate_import_path
- [ ] src/vallm/validators/imports/wrapper.py:7 - Relative import (level=1): '.factory'
- [ ] src/vallm/validators/imports.py:8 - Relative import (level=1): '.imports.wrapper'
- [ ] src/vallm/validators/lint.py:3 - Unused import: 'annotations'
- [ ] src/vallm/validators/lint.py:49 - Magic number: 20 - use named constant
- [ ] src/vallm/validators/lint.py:173 - LLM-style docstring in create_validator
- [ ] src/vallm/validators/lint.py:25 - LLM-style docstring in validate
- [ ] src/vallm/validators/lint.py:58 - LLM-style docstring in _check_ruff
- [ ] src/vallm/validators/logical.py:126 - String concatenation can be converted to f-string
- [ ] src/vallm/validators/logical.py:3 - Unused import: 'annotations'
- [ ] src/vallm/validators/logical.py:133 - LLM-style docstring in create_validator
- [ ] src/vallm/validators/logical.py:24 - LLM-style docstring in validate
- [ ] src/vallm/validators/logical.py:57 - LLM-style docstring in _check_pyflakes
- [ ] src/vallm/validators/security.py:3 - Unused import: 'annotations'
- [ ] src/vallm/validators/regression.py:153 - String concatenation can be converted to f-string
- [ ] src/vallm/validators/regression.py:3 - Unused import: 'annotations'
- [ ] src/vallm/validators/regression.py:8 - Unused import: 'textwrap'
- [ ] src/vallm/validators/regression.py:48 - Magic number: 120 - use named constant
- [ ] src/vallm/validators/regression.py:45 - LLM-style docstring in __init__
- [ ] src/vallm/validators/semantic.py:3 - Unused import: 'annotations'
- [ ] src/vallm/validators/semantic.py:168 - Magic number: 120 - use named constant
- [ ] src/vallm/validators/semantic.py:228 - Magic number: 500 - use named constant
- [ ] src/vallm/validators/semantic.py:245 - Magic number: 500 - use named constant
- [ ] src/vallm/validators/semantic_cache.py:3 - Unused import: 'annotations'
- [ ] src/vallm/validators/semantic_cache.py:9 - Unused import: 'Tuple'
- [ ] src/vallm/validators/semantic_cache.py:171 - LLM-style docstring in get_semantic_cache
- [ ] src/vallm/validators/semantic_cache.py:17 - LLM-style docstring in __init__
- [ ] src/vallm/validators/semantic_cache.py:30 - LLM-style docstring in _get_cache_key
- [ ] src/vallm/validators/syntax.py:3 - Unused import: 'annotations'
- [ ] test_mcp.py:27 - Function 'test_validate_syntax' missing return type (suggested: -> None)
- [ ] test_mcp.py:50 - Function 'test_validate_imports' missing return type (suggested: -> None)
- [ ] test_mcp.py:75 - Function 'test_validate_security' missing return type (suggested: -> None)
- [ ] test_mcp.py:8 - Unused import: 'json'
- [ ] test_mcp.py:66 - Import of non-existent module detected
- [ ] test_mcp.py:123 - Import of non-existent module detected
- [ ] test_mcp.py:145 - standalone main function
- [ ] test_mcp.py:165 - module execution block

---

*To execute all tasks, run: `prefact -a --execute-todos`*